EventInfo class

Constructors

EventInfo({required bool isSharing, required bool isExited, required bool isAccepted, DateTime? from})

Properties

from ↔ DateTime?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAccepted ↔ bool
getter/setter pair
isExited ↔ bool
getter/setter pair
isSharing ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited