MixedConstants class

Constructors

MixedConstants()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

API_KEY → String?
no setter
endTimeOptions ↔ List<String>
getter/setter pair
MAP_KEY → String?
no setter
startTimeOptions ↔ List<String>
getter/setter pair

Static Methods

setApiKey(String _key) → String
sets the API key used for API services
setMapKey(String _key) → String
sets the map key used for map services

Constants

CREATE_EVENT → const String
EVENT_MEMBER_LOCATION_KEY → const String